package com.compomics.scripts_marc;

import com.compomics.util.experiment.biology.AminoAcidSequence;
import com.compomics.util.preferences.SequenceMatchingPreferences;
import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.File;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;
import java.util.ArrayList;
import java.util.HashSet;

/**
 * Can be used to compare PeptideShaker Projects
 *
 * @author Marc Vaudel
 */
public class ProjectsComparison {

    private static final String separator = "\t";

    public static void main(String[] args) {
        ProjectsComparison m = new ProjectsComparison();

        try {
            System.out.println("Comparing peptides");
            m.comparePeptides();
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    private void comparePeptides() throws IOException {

        HashSet<String> mousePeptides = new HashSet<String>(10000);
        HashSet<String> parasitePeptides = new HashSet<String>(10000);

        File inFile = new File("D:\\projects\\parasite\\dialized peptides.txt");
        BufferedReader br = new BufferedReader(new FileReader(inFile));
        try {
            String line;
            while ((line = br.readLine()) != null) {
                String[] components = line.split(separator);
                String sequence = components[2];
                mousePeptides.add(sequence);
            }
        } finally {
            br.close();
        }

        inFile = new File("D:\\projects\\parasite\\raw peptides.txt");
        br = new BufferedReader(new FileReader(inFile));
        try {
            String line;
            while ((line = br.readLine()) != null) {
                String[] components = line.split(separator);
                String sequence = components[2];
                mousePeptides.add(sequence);
            }
        } finally {
            br.close();
        }

        inFile = new File("D:\\projects\\parasite\\leishmania extracellular peptides.txt");
        br = new BufferedReader(new FileReader(inFile));
        try {
            String line;
            while ((line = br.readLine()) != null) {
                String[] components = line.split(separator);
                String sequence = components[2];
                parasitePeptides.add(sequence);
            }
        } finally {
            br.close();
        }

        ArrayList<String> mouseOnly = new ArrayList<String>(mousePeptides.size());
        ArrayList<String> parasiteOnly = new ArrayList<String>(mousePeptides.size());
        ArrayList<String> common = new ArrayList<String>(mousePeptides.size());

        SequenceMatchingPreferences sequenceMatchingPreferences = new SequenceMatchingPreferences();
        sequenceMatchingPreferences.setLimitX(0.25);
        sequenceMatchingPreferences.setSequenceMatchingType(SequenceMatchingPreferences.MatchingType.indistiguishableAminoAcids);

        for (String sequence : mousePeptides) {
            boolean found = false;
            AminoAcidSequence aminoAcidSequence = new AminoAcidSequence(sequence);
            for (String tempSequence : parasitePeptides) {
                if (aminoAcidSequence.matches(tempSequence, sequenceMatchingPreferences)) {
                    if (!sequence.equals(tempSequence)) {
                        int debug = 1;
                    }
                    found = true;
                    break;
                }
            }
            if (found) {
                common.add(sequence);
            } else {
                mouseOnly.add(sequence);
            }
        }
        for (String sequence : parasitePeptides) {
            boolean found = false;
            AminoAcidSequence aminoAcidSequence = new AminoAcidSequence(sequence);
            for (String tempSequence : mousePeptides) {
                if (aminoAcidSequence.matches(tempSequence, sequenceMatchingPreferences)) {
                    if (!sequence.equals(tempSequence)) {
                        int debug = 1;
                    }
                    found = true;
                    break;
                }
            }
            if (!found) {
                parasiteOnly.add(sequence);
            }
        }

        File outFile = new File("D:\\projects\\parasite\\peptideSummary.txt");
        BufferedWriter bw = new BufferedWriter(new FileWriter(outFile));
        try {

            bw.write("Mouse only: " + mouseOnly.size() + " sequences");
            bw.newLine();
            bw.write("Leishmania only: " + parasiteOnly.size() + " sequences");
            bw.newLine();
            bw.write("Common: " + common.size() + " sequences");
            bw.newLine();
            bw.newLine();
            bw.write("Mouse only" + separator + "Leishmania only" + separator + "Common");
            bw.newLine();

            for (int i = 0; i < Math.max(mouseOnly.size(), Math.max(parasiteOnly.size(), common.size())); i++) {

                if (i < mouseOnly.size()) {
                    bw.write(mouseOnly.get(i));
                }
                bw.write(separator);
                if (i < parasiteOnly.size()) {
                    bw.write(parasiteOnly.get(i));
                }
                bw.write(separator);
                if (i < common.size()) {
                    bw.write(common.get(i));
                }
                bw.write(separator);
                bw.newLine();

            }

        } finally {
            bw.close();
        }
    }
}
